## Using AngularJS in Eclipse, Part 3) Wire up a Backend

This  covers the _**Wire up a Backend**_ example from [AngularJS](http://angularjs.org/http://angularjs.org/)'s home page:

![](images/Screen_Shot_2014-02-20_at_12_44_58.png)

**1) Creating the test files**

First step is to create a folder:

![](images/Screen_Shot_2014-02-20_at_12_48_54.png)

... called **_Wire a Backend_**

![](images/Screen_Shot_2014-02-20_at_12_49_17.png)

... to hold the 4 files required for this example: **_index.html, detail.html, list.html and project.js_**

![](images/Screen_Shot_2014-02-20_at_12_50_41.png)

Here is what they look like (with content from [http://angularjs.org](http://angularjs.org/))

**index.html :**

![](images/Screen_Shot_2014-02-20_at_12_51_18.png)

**project.js :**

![](images/Screen_Shot_2014-02-20_at_12_51_42.png)

**list.html :**

![](images/Screen_Shot_2014-02-20_at_12_52_01.png)

**detail.html :**

![](images/Screen_Shot_2014-02-20_at_12_52_19.png)

**2) Running in Browser and noticing CSS problems**

To see this example in action, lets open it in Eclipse's WebBrowser:

![](images/Screen_Shot_2014-02-20_at_12_54_26.png)

... which looks like this:

![](images/Screen_Shot_2014-02-20_at_12_54_50.png)

... with a search bar at the top that can be used to filter the loaded data:

![](images/Screen_Shot_2014-02-20_at_12_55_18.png)

Only problem is that it doesn't look at all like it does on the [http://angularjs.org](http://angularjs.org/) page (see below)

![](images/Screen_Shot_2014-02-20_at_12_56_10.png)

Note how not only the css styles are different, the **_add_** and **_edit_** links (i.e. icons) are missing:

![](images/Screen_Shot_2014-02-20_at_12_56_26.png)

Here is what the **_edit_** page should look like:

![](images/Screen_Shot_2014-02-20_at_12_56_33.png)

Here is what the _new_ page should look like:

![](images/Screen_Shot_2014-02-20_at_12_56_40.png)


**3) Running example on JSFiddle**  

On the [http://angularjs.org](http://angularjs.org/) page there is a button called _Edit Me_ (top right) which when clicked will do a cross-site POST submission to [http://jsfiddle.net/api/post/library/pure/](http://jsfiddle.net/api/post/library/pure/)

![](images/Screen_Shot_2014-02-20_at_12_57_02.png)

... which looks like this (notice the extra [Bootstrap](http://getbootstrap.com/) css included that is not present on the code sample provided in the [http://angularjs.org](http://angularjs.org/) page )

![](images/Screen_Shot_2014-02-20_at_12_57_23.png)

For reference here is what the _Edit Me_ form looks like in the [http://angularjs.org](http://angularjs.org/) page (with the values passed as hidden parameters to **_jsfiddle_**)

![](images/Screen_Shot_2014-02-21_at_10_32_05.png)

And here is the jsfiddle API description for the method used ([http://doc.jsfiddle.net/api/post.html](http://doc.jsfiddle.net/api/post.html))

![](images/Screen_Shot_2014-02-21_at_10_32_14.png)

**4) Fixing CSS issue**

Since I wanted to match the CSS of my local test page to the style used in the example embedded in the  [http://angularjs.org](http://angularjs.org/) page, the best place to look is on the source code code of that page :)

Using Chrome Browser Inspector, on the _Styles_ tab, I was able to see that they were using two css libraries: [Bootstrap](http://getbootstrap.com/) and [Font Awesome](http://fortawesome.github.io/Font-Awesome/):

![](images/Screen_Shot_2014-02-20_at_13_00_14.png)

Back in Eclipse, I added the bootstrap css reference

![](images/Screen_Shot_2014-02-20_at_13_00_45.png)

And on refresh, the page looked better (but the **_edit_** and **_add_** icons/links where still missing)

![](images/Screen_Shot_2014-02-20_at_13_00_53.png)

So I went back to the angularjs.org source code to see what they were using:

![](images/Screen_Shot_2014-02-20_at_13_01_24.png)

First I tried adding the latest [Font Awesome](http://fortawesome.github.io/Font-Awesome/) from their CDN:

![](images/Screen_Shot_2014-02-20_at_13_03_44.png)

But since that didn't work, I decided to add both **font-awesome.css** an **docs.css** references:

![](images/Screen_Shot_2014-02-20_at_13_03_54.png)

... with much better results (note the icons on the right)

![](images/Screen_Shot_2014-02-20_at_13_04_03.png)

But there was still something wrong, since the **_new_** page looked like this:

![](images/Screen_Shot_2014-02-20_at_13_04_46.png)

... and the **_edit_** page looked like this:  

![](images/Screen_Shot_2014-02-20_at_13_05_27.png)

Since it was all good on the angular.org site, my next try was to use the **_bootstrap.min.css_** file from it (vs the CDN)

![](images/Screen_Shot_2014-02-20_at_13_06_34.png)

With the local page:

![](images/Screen_Shot_2014-02-20_at_13_07_00.png)

... and the **_edit_** page now looking just like the real thing (note the Search TextBox (above) and the fields (below))

![](images/Screen_Shot_2014-02-20_at_13_07_09.png)

That said, the layout where still a little bit different (namely the background of the local file which was white).

So I had a look at the style of the example in angular.org and noticed that there was a _div_ element with the bootstrap classes **well** and **ng-scope**:

![](images/Screen_Shot_2014-02-20_at_13_09_12.png)

Back in the local file, I edited the index.html to also have a similar div:

![](images/Screen_Shot_2014-02-20_at_13_09_24.png)

And finally the local form looked just like the original:

![](images/Screen_Shot_2014-02-20_at_13_09_41.png)

**5) Running local sample on multiple browsers**

At this stage I was curious on what this form would look like on multiple browsers, and found out something interesting.

Here is the page on Safari (left) and Firefox (right), which are loaded ok:

![](images/Screen_Shot_2014-02-20_at_13_11_32.png)

But on Chrome, it doesn't work at all, and the culprit is security!

![](images/Screen_Shot_2014-02-20_at_13_12_02.png)

Basically chrome does not allow Cross origin requests from html files loaded from the local disk (which does make sense from a security point of view).

As a final little comment, in case you noticed that on the Firefox screenshot the Angular content was correctly displayed but the icons didn't show up, that much be a similar problem with loading **_Bootstrap_** or **_Font Awesome_** from the local disk

![](images/Screen_Shot_2014-02-21_at_10_57_01.png)

Here is the same example running on Firefox browser, so it works when loaded from http:

![](images/Screen_Shot_2014-02-21_at_11_01_06.png)
