##  AngularJS code editor using UI-Bootstrap and CodeMirror (done without using jQuery)

I'm adding a number of [AngularJS](http://docs.angularjs.org/) views to [TeamMentor](http://blog.diniscruz.com/search/label/TeamMentor), and here is a simple HTML based source code editor inspired on the [How to Integrate Codemirror With Angular UI](http://neverstopbuilding.net/how-to-integrate-codemirror-with-angular-ui/) post and [ui-codemirror](https://github.com/angular-ui/ui-codemirror) repository.

In the end, these are the APIs I used:  

  * [http://angularjs.org/](http://angularjs.org/)
  * [http://angular-ui.github.io/bootstrap/](http://angular-ui.github.io/bootstrap/)
  * [http://twitter.github.io/bootstrap](http://twitter.github.io/bootstrap)
  * [http://codemirror.net/](http://codemirror.net/) (just the core bit)

And this is what it looks like:

![](images/image_thumb-1.png)

The source code editor is showing the contents of the current page (dynamically fetched using Angular **_$http.get_**) and the bottom yellow div is showing (in real-time) the contents of the source code editor:

![](images/image_thumb-2.png)

**What is nice about this example is that I didn't use jQuery at all!**

The great posts [http://stackoverflow.com/a/15012542](http://stackoverflow.com/a/15012542) and [AngularJS for jQuery Developers](http://blog.artlogic.com/2013/03/06/angularjs-for-jquery-developers/) explain why learning to code in Angular without JQuery is so important.

Basically, it's better not  have jQuery available, since them, the only way to solve a problem, is the 'AngularJS way' :)

**How it works:**  

Here is a brief explanation of the code behind this PoC (included in full at the end of this page):

First we load the **Javascript** and **CSS:**  

![](images/image_thumb-3.png)

... them set up **_AngularJS_** module and **_codeMirror_** value

![](images/image_thumb-4.png)

... use a **_controller_** to get the code to show (using **_$http.get_**) and assign it to the the**_ $scope.code_** variable

![](images/image_thumb-5.png)

... configure **angularJS** in the HTML by setting the **_textarea_** element to be a **_codemirror_** (linked to the **$scope.code** model)

![](images/image_thumb-6.png)

... finally show the current value of **$scope.code** in side an bootstrap **_alert_** element

![](images/image_thumb-7.png)

**Complete Source code:**  

{lang="html"}
    <!DOCTYPE html>

    <html>  
        <head>  
            <title>CodeMirror with AngularJS</title>  
            <link href="/Content/bootstrap.min.css" rel="stylesheet">  
            <script src="/Scripts/angular.min.js" type="text/javascript"></script>  
            <script src="/Scripts/angular-ui.js" type="text/javascript"></script>  
            <script src="/Scripts/ui-bootstrap-tpls-0.3.0.min.js" type="text/javascript"></script>

            <link href="/Content/codemirror-3.01/codemirror.css" rel="stylesheet"/>  
            <link href="/Content/codemirror-3.01/theme/rubyblue.css" rel="stylesheet"/>  
            <script src="/Scripts/codemirror-3.01/codemirror.js" type="text/javascript"></script>  
            <script src="/Scripts/codemirror-3.01/mode/javascript.js" type="text/javascript"></script>


            <script type="text/javascript">  
                var myApp = angular.module('myApp', ['ui', 'ui.bootstrap']);

                myApp.value('ui.config',  
                    {  
                        codemirror:  
                            {  
                                mode: 'javascript',  
                                lineNumbers: true,  
                                matchBrackets: true,  
                                theme: 'rubyblue'  
                            }  
                    });

                function codeCtrl($scope,$http)  
                {  
                    $scope.docLocation = document.location.href;  
                    $http.get($scope.docLocation)  
                         .success(function (data)  
                            {  
                                $scope.code = data;  
                            });  
                    //$scope.code = "var a = 'somecode'; \n//which also shows above</h1>";  
                }  
            </script>  
        </head>  
        <body ng-app="myApp">  
            <div class="well well-large">  
                <div class="container">  
                    <h2>CodeMirror working with AngularJS and Bootstrap</h2></div>  
                </div>  
                <div ng-controller="codeCtrl">  
                    <div class="container">

                    <h4>Code Editor:</h4>  
                    <p>With the the contents of this page (i.e.: {{docLocation}} )</p>

                    <textarea ui-codemirror ng-model="code"></textarea>

                    <br/><hr/><br/>

                    <h4>Bootstrap alert style</h4>  
                    <p>  
                        Showing in real time the contents of the code shown above (make a change to try it)  
                    </p>  
                    <alert type="success">{{code}}</alert>  
                </div>  
            </div>  
        </body>  
    </html>  
